as_is: Mark as a node to inject as is

View source: R/as_is.R

as_isR Documentation

Mark as a node to inject as is

Description

Mark as a node to inject as is

Usage

as_is(x, error_call = current_env())

Arguments

x

raw ooxml passed through as_xml_node()

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

adds the class "as_is" to the input text the content "as is" and not modify it when polishing


polish documentation built on June 3, 2026, 5:07 p.m.