Convert to xml nodes

as_xml_nodeset(
  x,
  ns = c("word", "pptx"),
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

as_xml_node(
  x,
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

as_xml_node_word(
  x,
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

as_xml_node_pptx(
  x,
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

as_xml_word(
  x,
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

as_xml_pptx(
  x,
  ...,
  .envir = parent.frame(),
  .open = "{",
  .close = "}",
  error_call = current_env()
)

Arguments

x

an object to convert to xml nodes

ns

word or pptx

...

These dots are for future extensions and must be empty.

.envir, .open, .close

forwarded to glue::glue()

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

an xml_nodeset