Wrapper around rlang::check_dots_empty() that only does the check if the polish.dots_error is set to TRUE

polish_check_dots_empty(env = caller_env(), error = NULL, call = caller_env())

Arguments

env

Environment in which to look for ....

error

An optional error handler passed to try_fetch(). Use this e.g. to demote an error into a warning.

call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.