Polish content

polish_content(x, type, ..., error_call = current_env(), error_class = NULL)

Arguments

x

object to be polished into ooxml

type

output type. Valid values are "word" and "pptx".

...

additional arguments for methods

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

error_class

Additional error class.

Details

depending on type either the polish_content_pptx() or polish_content_word() function is called.