| show_xml | R Documentation |
Show the xml of the polished version of a display in the browser
show_xml(xml, wrap = TRUE)
xml |
an xml node or nodeset |
wrap |
if TRUE, the xml is wrapped in a w:body node |
This opens the xml in the browser, so that you can do View source and inspect the structure of the xml
used for side effect of previewing xml in a browser. Helpful for inspecting the OOXML generated by this package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.