sp_shell: Wrap the placeholder into a <p:sp> shell

View source: R/pptx.R

sp_shellR Documentation

Wrap the placeholder into a <p:sp> shell

Description

Wrap the placeholder into a <p:sp> shell

Usage

sp_shell(ph, error_call = current_env())

Arguments

ph

placeholder

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

an object of class "polish_xml_nodeset". Contains XML that is viable PowerPoint OOXML for addition to PowerPoint documents.


polish documentation built on June 3, 2026, 5:07 p.m.