xml_nodeset_ns_spec: xml namespaces

View source: R/xml.R

xml_nodeset_ns_specR Documentation

xml namespaces

Description

xml namespaces

Usage

xml_nodeset_ns_spec(ns = c("word", "pptx"), error_call = caller_env())

Arguments

ns

word or pptx

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

xml namespaces for word or pptx


polish documentation built on June 3, 2026, 5:07 p.m.