Mark as a node to inject as is

as_is(x, error_call = current_env())

Arguments

x

raw ooxml passed through as_xml_node()

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.