Polish content for Powerpoint
# S3 method for class 'flextable'
polish_content_pptx(
x,
ph = "<p:ph/>",
...,
full_width = FALSE,
page_size = NULL,
table_style = NULL,
pptx = NULL,
error_call = current_env()
)
# S3 method for class 'ggplot'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
height = NULL,
width = NULL,
res = 300,
device = c("png", "svg", "jpeg"),
scale = 1,
error_call = current_env()
)
polish_content_pptx(x, ph = "<p:ph/>", pptx, ..., error_call = current_env())
# S3 method for class 'character'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
escape = TRUE,
collapse = FALSE,
font_color = NULL,
font_style = NULL,
font_size = NULL,
font_typeface = NULL,
error_call = current_env()
)
# S3 method for class 'list'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
list_type = c("none", "unordered", "ordered"),
error_call = current_env()
)
# S3 method for class 'file_png'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
height = NULL,
width = NULL,
units = "in",
image_fit = c("stretch", "scale"),
error_call = current_env()
)object to be polished
placeholder
These dots are for future extensions and must be empty.
Logical, used to fit full size of given width
Number of rows to accommodate in a slide
Named list with two entries: style and options. style is the name of table style to apply as a character, options a character vector of options to apply from the table style, including: "Banded Columns", "Banded Rows", "First Column", "Header Row", "Last Column", and "Total Row"
The powerpoint presentation.
The execution environment of a currently
running function, e.g. caller_env(). The function will be
mentioned in error messages as the source of the error. See the
call argument of abort() for more information.
defaults to match the height and width of the placeholder provided. When that cannot be derived, it assumes the plot should be 5 inches tall and 6 inches wide. Users may set the width and height, but they most both be set.
Plot resolution. Also accepts a string input: "retina" (320), "print" (300), or "screen" (72). Applies only to raster output types.
what graphic device to use when saving the plot. Can be one of "png","svg", or "jpeg".
Multiplicative scaling factor to use when saving the plot. See ggplot2::ggsave.
Should x be escaped with htmltools::htmlEscape()
If TRUE a <a:br w:type="textWrapping" w:clear="all"> element is added between the <a:r> nodes
color of text. Enter as a hex code.
styling of text, vector including "bold","italic","underline".
point size of text if different from document default.
typeface of the text to be added if different from document default.
How to print the list. Options are "none", "unordered" and "ordered".
"none" (default) puts contents on new lines and indents lists accordingly.
"unordered" makes the content bulleted list with indents.
"ordered" makes a numbered list with intents.
Should the image be distorted to match the dimensions of the placeholder, or scaled up/down and keep dimension ratio (scale). Default is "stretch".