| polish_content_pptx.flextable | R Documentation |
Polish content for Powerpoint
## S3 method for class 'flextable'
polish_content_pptx(
x,
ph = "<p:ph/>",
...,
full_width = FALSE,
page_size = NULL,
table_style = NULL,
pptx = NULL,
error_call = current_env()
)
## S3 method for class 'ggplot'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
height = NULL,
width = NULL,
res = 300,
device = c("png", "svg", "jpeg"),
scale = 1,
error_call = current_env()
)
polish_content_pptx(x, ph = "<p:ph/>", pptx, ..., error_call = current_env())
## S3 method for class 'character'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
escape = TRUE,
collapse = FALSE,
font_color = NULL,
font_style = NULL,
font_size = NULL,
font_typeface = NULL,
error_call = current_env()
)
## S3 method for class 'list'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
list_type = c("none", "unordered", "ordered"),
error_call = current_env()
)
## S3 method for class 'file_png'
polish_content_pptx(
x,
ph = "<p:ph/>",
pptx,
...,
height = NULL,
width = NULL,
units = "in",
image_fit = c("stretch", "scale"),
error_call = current_env()
)
x |
object to be polished |
ph |
placeholder |
... |
These dots are for future extensions and must be empty. |
full_width |
Logical, used to fit full size of given width |
page_size |
Number of rows to accommodate in a slide |
table_style |
Named list with two entries: style and options. style is the name of table style to apply as a character, options a character vector of options to apply from the table style, including: "Banded Columns", "Banded Rows", "First Column", "Header Row", "Last Column", and "Total Row" |
pptx |
The Powerpoint Presentation object |
error_call |
The execution environment of a currently
running function, e.g. |
width, height |
defaults to match the height and width of the placeholder provided. When that cannot be derived, it assumes the plot should be 5 inches tall and 6 inches wide. Users may set the width and height, but they most both be set. |
res |
Plot resolution. Also accepts a string input: "retina" (320), "print" (300), or "screen" (72). Applies only to raster output types. |
device |
what graphic device to use when saving the plot. Can be one of "png","svg", or "jpeg". |
scale |
Multiplicative scaling factor to use when saving the plot. See ggplot2::ggsave. |
escape |
Should |
collapse |
If |
font_color |
color of text. Enter as a hex code. |
font_style |
styling of text, vector including "bold","italic","underline". |
font_size |
point size of text if different from document default. |
font_typeface |
typeface of the text to be added if different from document default. |
list_type |
How to print the list. Options are "none", "unordered" and "ordered".
|
units |
see officer::external_img |
image_fit |
Should the image be distorted to match the dimensions of the placeholder, or scaled up/down and keep dimension ratio (scale). Default is "stretch". |
a "polish_xml_nodeset" of viable PowerPoint OOXML for addition to PowerPoint presentations.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.