Show the xml of the polished version of a display in the browser

show_xml(xml, wrap = TRUE)

Arguments

xml

an xml node or nodeset

wrap

if TRUE, the xml is wrapped in a w:body node

Value

used for side effect of previewing xml in a browser. Helpful for inspecting the OOXML generated by this package.

Details

This opens the xml in the browser, so that you can do View source and inspect the structure of the xml