Show the xml of the polished version of a display in the browser

show_xml(xml, wrap = TRUE)

Arguments

xml

an xml node or nodeset

wrap

if TRUE, the xml is wrapped in a w:body node

Details

This opens the xml in the browser, so that you can do View source and inspect the structure of the xml