Wrap the placeholder into a <p:sp> shell

sp_shell(ph, error_call = current_env())

Arguments

ph

placeholder

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.